@@ -149,42 +149,11 @@ class RootAuthenticator(BaseAuthenticator):
 
     def _get_console_root_session(self, redirect_url):
         service = 'console'
-        home_url_response = self._get_response(redirect_url, extra_cookies=[FilterCookie('JSESSIONID', ),
-                                                                            FilterCookie('aws-userInfo-signed', ),
-                                                                            FilterCookie('aws-creds', ),
+        home_url_response = self._get_response(redirect_url, extra_cookies=[FilterCookie('aws-userInfo-signed', ),
                                                                             FilterCookie('aws-creds-code-verifier', )])
         url = home_url_response.headers.get('Location')
-        _ = self._get_response(url, extra_cookies=[FilterCookie('aws-userInfo-signed', ),
-                                                   FilterCookie('aws-creds', f'{service}'),
-                                                   FilterCookie('aws-creds-code-verifier',
-                                                                f'{service}')])
-        url = f'{self.urls.regional_console_home}'
-        params = {'region': self.region}
-        _ = self._get_response(url,
-                               params=params,
-                               extra_cookies=[FilterCookie('JSESSIONID', ),
-                                              FilterCookie('aws-userInfo-signed', ),
-                                              FilterCookie('aws-creds', f'{service}'),
-                                              FilterCookie('aws-creds-code-verifier',
-                                                           f'{service}')])
-        params.update({'hashArgs': '#'})
-        hash_args = self._get_response(url,
-                                       params=params,
-                                       extra_cookies=[FilterCookie('JSESSIONID', ),
-                                                      FilterCookie('aws-userInfo-signed', ),
-                                                      FilterCookie('aws-creds', f'{service}'),
-                                                      FilterCookie('aws-creds-code-verifier', f'{service}')])
-        oauth_url = hash_args.headers.get('Location')
-        oauth = self._get_response(oauth_url,
-                                   extra_cookies=[FilterCookie('aws-creds', self.domains.sign_in),
-                                                  FilterCookie('aws-userInfo-signed', )])
-        oauth_challenge = self._get_response(oauth.headers.get('Location'),
-                                             extra_cookies=[FilterCookie('JSESSIONID', self.urls.regional_console),
-                                                            FilterCookie('aws-userInfo-signed', ),
-                                                            FilterCookie('aws-creds-code-verifier', f'/{service}')])
-        dashboard = self._get_response(oauth_challenge.headers.get('Location'),
-                                       extra_cookies=[FilterCookie('aws-creds', f'/{service}'),
-                                                      FilterCookie('JSESSIONID', )])
+        dashboard = self._get_response(url, extra_cookies=[FilterCookie('aws-userInfo-signed', ),
+                                                           FilterCookie('aws-creds', f'{service}', )])
         if not dashboard.ok:
             self.logger.error(f'Received broken response: {dashboard.text}')
         return dashboard.ok
@@ -204,25 +173,35 @@ class RootAuthenticator(BaseAuthenticator):
         if not self._get_console_root_session(redirect_url):
             raise InvalidAuthentication('Unable to get a valid authenticated session for root console.')
         service = 'billing'
-        url = f'{self.urls.billing_home}?#/account'
-        _ = self._session.get(url)
-        url = f'{self.urls.billing_home}'
-        hash_args = self._get_response(url,
+
+        _ = self._get_response(self.urls.billing_home)
+
+        hash_args = self._get_response(self.urls.billing_home,
                                        params={'state': 'hashArgs#'},
-                                       extra_cookies=[FilterCookie('JSESSIONID', ),
-                                                      FilterCookie('aws-userInfo-signed', ),
+                                       extra_cookies=[FilterCookie('aws-userInfo-signed', ),
                                                       FilterCookie('aws-creds-code-verifier', f'/{service}')])
-        oauth = self._get_response(hash_args.headers.get('Location'),
+        _ = self._get_response(hash_args.headers.get('Location'),
+                               extra_cookies=[
+                                   FilterCookie('aws-userInfo-signed', )])
+
+        billing_response = self._get_response(self.urls.global_billing_home,
+                                              params={'state': 'hashArgs#', 'skipRegion': 'true',
+                                                      'region': 'us-east-1'},
+                                              extra_cookies=[FilterCookie('aws-userInfo-signed', ),
+                                                             FilterCookie('aws-creds-code-verifier', f'/{service}')])
+
+        oauth = self._get_response(billing_response.headers.get('Location'),
                                    extra_cookies=[FilterCookie('aws-creds', self.domains.sign_in),
-                                                  FilterCookie('aws-userInfo-signed', )])
+                                                  FilterCookie('aws-userInfo-signed', ),
+                                                  FilterCookie('aws-signin-account-info', )])
+
         oauth_challenge = self._get_response(oauth.headers.get('Location'),
-                                             extra_cookies=[FilterCookie('JSESSIONID', self.urls.regional_console),
-                                                            FilterCookie('aws-userInfo-signed', ),
+                                             extra_cookies=[FilterCookie('aws-userInfo-signed', ),
                                                             FilterCookie('aws-creds-code-verifier', f'/{service}')
                                                             ])
+
         dashboard = self._get_response(oauth_challenge.headers.get('Location'),
-                                       extra_cookies=[FilterCookie('aws-creds', f'/{service}'),
-                                                      FilterCookie('JSESSIONID')])
+                                       extra_cookies=[FilterCookie('aws-creds', f'/{service}')])
         if unfiltered_session:
             return self._session
         csrf_token_data = CsrfTokenData(entity_type='input',
@@ -231,7 +210,7 @@ class RootAuthenticator(BaseAuthenticator):
                                         headers_name='x-awsbc-xsrf-token')
         extra_cookies = [FilterCookie('aws-creds', f'/{service}'),
                          FilterCookie('aws-signin-csrf', '/signin'),
-                         FilterCookie('JSESSIONID', )]
+                         ]
         return self._get_session_from_console(dashboard, csrf_token_data, extra_cookies)
 
     def get_iam_root_session(self, redirect_url):
@@ -251,40 +230,38 @@ class RootAuthenticator(BaseAuthenticator):
         _ = self._session.get(url)
         hash_args = self._get_response(url,
                                        params={'state': 'hashArgs#'},
-                                       extra_cookies=[FilterCookie('cfn_sessid', ),
-                                                      FilterCookie('awsccc', ),
-                                                      FilterCookie('aws-csds-token', ),
+                                       extra_cookies=[FilterCookie('aws-userInfo-signed', ),
                                                       FilterCookie('aws-creds-code-verifier', f'/{service}')])
-        oauth = self._get_response(hash_args.headers.get('Location'),
+        _ = self._get_response(hash_args.headers.get('Location'),
+                               extra_cookies=[
+                                   FilterCookie('aws-userInfo-signed', )])
+
+        regional_response = self._get_response(self.urls.global_iam_home,
+                                               params={'state': 'hashArgs#', 'skipRegion': 'true',
+                                                       'region': 'us-east-1'},
+                                               extra_cookies=[FilterCookie('aws-userInfo-signed', ),
+                                                              FilterCookie('aws-creds-code-verifier', f'/{service}')])
+
+        oauth = self._get_response(regional_response.headers.get('Location'),
                                    extra_cookies=[FilterCookie('aws-creds', self.domains.sign_in),
-                                                  FilterCookie('cfn_sessid', ),
                                                   FilterCookie('aws-userInfo-signed', ),
-                                                  FilterCookie('aws-csds-token', ),
-                                                  FilterCookie('aws-creds', f'/{service}'),
-                                                  FilterCookie('JSESSIONID', ),
-                                                  FilterCookie('aws-userInfo-signed', )])
+                                                  FilterCookie('aws-signin-account-info', )])
+
         oauth_challenge = self._get_response(oauth.headers.get('Location'),
-                                             extra_cookies=[FilterCookie('JSESSIONID',),
-                                                            FilterCookie('awsccc', ),
-                                                            FilterCookie('aws-csds-token', ),
-                                                            FilterCookie('cfn_sessid', ),
-                                                            FilterCookie('aws-userInfo-signed', ),
+                                             extra_cookies=[FilterCookie('aws-userInfo-signed', ),
                                                             FilterCookie('aws-creds-code-verifier', f'/{service}')
                                                             ])
+
         dashboard = self._get_response(oauth_challenge.headers.get('Location'),
-                                       extra_cookies=[FilterCookie('aws-creds', f'/{service}'),
-                                                      FilterCookie('aws-creds-code-verifier', f'/{service}'),
-                                                      FilterCookie('cfn_sessid', ),
-                                                      FilterCookie('awsccc', ),
-                                                      FilterCookie('aws-userInfo-signed', ),
-                                                      FilterCookie('aws-consoleInfo', )])
+                                       extra_cookies=[FilterCookie('aws-creds', f'/{service}')])
+
         csrf_token_data = CsrfTokenData(entity_type='meta',
                                         attributes={'id': 'xsrf-token'},
                                         attribute_value='data-token',
                                         headers_name='X-CSRF-TOKEN')
         extra_cookies = [FilterCookie('aws-creds', f'/{service}'),
-                         FilterCookie('aws-creds-code-verifier', f'/{service}'),
-                         FilterCookie('aws-consoleInfo', )]
+                         FilterCookie('aws-signin-csrf', '/signin'),
+                         ]
         return self._get_session_from_console(dashboard, csrf_token_data, extra_cookies)
 
 
@@ -464,7 +441,7 @@ class BaseConsoleInterface(LoggerMixin):
         return success
 
     def _resolve_account_type(self, email):
-        response = self._resolve_account_type_response(email, {'hashArgs': '#a'})
+        response = self._resolve_account_type_response(email)
         success = self._validate_response(response)
         if not success:
             raise UnableToResolveAccount(f'Failed to resolve account type with response: {response.text} '
@@ -472,15 +449,16 @@ class BaseConsoleInterface(LoggerMixin):
         self.logger.debug(f'Resolved account type successfully with response :{response.text}')
         return success
 
-    def _resolve_account_type_response(self, email, extra_parameters=None, session=None):
+    def _resolve_account_type_response(self, email, session=None):
         session_ = session if session else self.session
+
         parameters = {'action': 'resolveAccountType',
-                      'email': email}
-        if extra_parameters:
-            parameters.update(extra_parameters)
-        _ = session_.get(self._console_home_url, params=parameters)
-        parameters.update({'csrf': session_.cookies.get('aws-signin-csrf', path='/signin')})
+                      'email': email,
+                      'csrf': session_.cookies.get('aws-signin-csrf', path='/signin')}
         response = session_.post(self._signin_url, data=parameters)
+        if response.json().get('properties', {}).get('CaptchaURL') is None:
+            self.logger.debug('No Captcha information found.')
+            return response
         self.logger.debug('Getting the resolve account type captcha.')
         parameters = self._update_parameters_with_captcha(parameters, response)
         return session_.post(self._signin_url, data=parameters)
@@ -512,8 +490,11 @@ class BaseConsoleInterface(LoggerMixin):
         return None if mfa_type == 'NONE' else mfa_type
 
     def _get_root_console_redirect(self, email, password, session, mfa_serial=None):
-        url = Urls.console_home
-        parameters = {'hashArgs': '#a'}
+
+        urls = Urls('us-east-1')
+        url = urls.regional_console_home
+        parameters = {'hashArgs': '#a', 'skipRegion': 'true', 'region': 'us-east-1'}
+
         self.logger.debug(f'Trying to get url: {url} with parameters :{parameters}')
         response = session.get(url, params=parameters)
         if not response.ok:
@@ -521,8 +502,12 @@ class BaseConsoleInterface(LoggerMixin):
                               f'with status code: {response.status_code}')
         oidc = self._get_oidc_info(response.history[0].headers.get('Location'))
         response = self._resolve_account_type_response(email, session=session)
+        captcha_url = response.json().get('properties', {}).get('CaptchaURL')
+        captcha_status_token = response.json().get('properties', {}).get('captchaStatusToken')
+
         if any([not response.ok,
-                response.json().get('properties', {}).get('captchaStatusToken') is None]):
+                all([captcha_url is not None,
+                     captcha_status_token is None])]):
             raise UnableToResolveAccount(f'Unable to resolve the account, response received: {response.text} '
                                          f'with status code: {response.status_code}')
         mfa_type = self.get_mfa_type(email)
@@ -533,7 +518,6 @@ class BaseConsoleInterface(LoggerMixin):
             if not mfa_type == 'SW':
                 raise UnsupportedMFA('Currently on SW mfa type is supported.')
         parameters = {'action': 'authenticateRoot',
-                      'captcha_status_token': response.json().get('properties', {}).get('captchaStatusToken'),
                       'client_id': oidc.client_id,
                       'code_challenge_method': oidc.code_challenge_method,
                       'code_challenge': oidc.code_challenge,
@@ -542,6 +526,10 @@ class BaseConsoleInterface(LoggerMixin):
                       'password': password,
                       'redirect_uri': oidc.redirect_url,
                       'csrf': session.cookies.get('aws-signin-csrf', path='/signin')}
+
+        if captcha_url is not None:
+            parameters['captcha_status_token'] = captcha_status_token
+
         if mfa_type:
             totp = TOTP(mfa_serial)
             parameters.update({'mfaType': mfa_type,
@@ -584,6 +572,10 @@ class PasswordManager(BaseConsoleInterface):
 
         """
         self.logger.debug(f'Trying to resolve account type for email :{email}')
+
+        urls = Urls('us-east-1')
+        _ = self.session.get(urls.regional_console_home, params={'hashArgs': '#a', 'region': 'us-east-1'})
+
         try:
             self._resolve_account_type(email)
         except UnableToResolveAccount:
