@@ -523,8 +523,23 @@ class OrganizationsOU:
         """The arn of the OU."""
         return self._data.get('Arn')
 
+    @property
+    def parent_ou_id(self):
+        """The id of the parent."""
+        return self._data.get('ParentId')
 
-class ControlTowerOU:
+    @property
+    def parent_ou_arn(self):
+        """The arn of the parent."""
+        return self._data.get('ParentArn')
+
+    @property
+    def parent_ou_name(self):
+        """The name of the parent."""
+        return self._data.get('ParentName')
+
+
+class ControlTowerOU(LoggerMixin):
     """Model the data of a Control Tower managed OU."""
 
     def __init__(self, control_tower, data):
@@ -574,3 +589,52 @@ class ControlTowerOU:
 
         """
         return self.control_tower.delete_organizational_unit(self.name)
+
+    @property
+    def child_ous(self):
+        """The list child OUs for this ou.
+
+        Returns:
+            response (list): List of Child OUs
+
+        """
+        payload = self.control_tower._get_api_payload(content_string={'OrganizationalUnitId': self.id},  # pylint: disable=protected-access
+                                                      target='describeManagedOrganizationalUnit')
+        response = self.control_tower.session.post(self.control_tower.url, json=payload)
+        if not response.ok:
+            self.logger.error('Failed to get Child OUs')
+            return []
+        return [ControlTowerOU(self.control_tower, _data) for _data in
+                response.json().get('ChildrenOrganizationalUnits')]
+
+
+class ResultOU:
+    """Model the data of an child OU described by the api."""
+
+    def __init__(self, data):
+        self._data = data
+
+    @property
+    def id(self):  # pylint: disable=invalid-name
+        """The id of the OU."""
+        return self._data.get('OrganizationalUnitId')
+
+    @property
+    def name(self):
+        """The name of the OU."""
+        return self._data.get('OrganizationalUnitName')
+
+    @property
+    def status(self):
+        """The status of the OU."""
+        return self._data.get('OrganizationalUnitStatus')
+
+    @property
+    def parent_ou_id(self):
+        """The id of the parent."""
+        return self._data.get('ParentOrganizationalUnitId')
+
+    @property
+    def create_date(self):
+        """The timestamp of the creation."""
+        return self._data.get('CreateDate')
